.\" Copyright (c) 2001-2003 The Open Group, All Rights Reserved 
.TH "PUTS" P 2003 "IEEE/The Open Group" "POSIX Programmer's Manual"
.\" puts 
.SH NAME
puts \- put a string on standard output
.SH SYNOPSIS
.LP
\fB#include <stdio.h>
.br
.sp
int puts(const char *\fP\fIs\fP\fB);
.br
\fP
.SH DESCRIPTION
.LP
The \fIputs\fP() function shall write the string pointed to by \fIs\fP,
followed by a <newline>, to the standard output
stream \fIstdout\fP. The terminating null byte shall not be written.
.LP
The
\fIst_ctime\fP and \fIst_mtime\fP fields of the file shall be marked
for update between the successful execution of \fIputs\fP()
and the next successful completion of a call to \fIfflush\fP() or
\fIfclose\fP() on the same stream or a call to \fIexit\fP()
or \fIabort\fP(). 
.SH RETURN VALUE
.LP
Upon successful completion, \fIputs\fP() shall return a non-negative
number. Otherwise, it shall return EOF, shall set an error
indicator for the stream,   \ and \fIerrno\fP shall be set to indicate
the error. 
.SH ERRORS
.LP
Refer to \fIfputc\fP() .
.LP
\fIThe following sections are informative.\fP
.SH EXAMPLES
.SS Printing to Standard Output
.LP
The following example gets the current time, converts it to a string
using \fIlocaltime\fP() and \fIasctime\fP(), and prints it to
standard output using \fIputs\fP(). It then prints the number of minutes
to an event for which it is waiting.
.sp
.RS
.nf

\fB#include <time.h>
#include <stdio.h>
\&...
time_t now;
int minutes_to_event;
\&...
time(&now);
printf("The time is ");
puts(asctime(localtime(&now)));
printf("There are %d minutes to the event.\\n",
    minutes_to_event);
\&...
\fP
.fi
.RE
.SH APPLICATION USAGE
.LP
The \fIputs\fP() function appends a <newline>, while \fIfputs\fP()
does not.
.SH RATIONALE
.LP
None.
.SH FUTURE DIRECTIONS
.LP
None.
.SH SEE ALSO
.LP
\fIfopen\fP() , \fIfputs\fP() , \fIputc\fP() , the
Base Definitions volume of IEEE\ Std\ 1003.1-2001, \fI<stdio.h>\fP
.SH COPYRIGHT
Portions of this text are reprinted and reproduced in electronic form
from IEEE Std 1003.1, 2003 Edition, Standard for Information Technology
-- Portable Operating System Interface (POSIX), The Open Group Base
Specifications Issue 6, Copyright (C) 2001-2003 by the Institute of
Electrical and Electronics Engineers, Inc and The Open Group. In the
event of any discrepancy between this version and the original IEEE and
The Open Group Standard, the original IEEE and The Open Group Standard
is the referee document. The original Standard can be obtained online at
http://www.opengroup.org/unix/online.html .
